@@ -14,6 +14,10 @@ class Attachment:
 
         file = element.find('cbc:EmbeddedDocumentBinaryObject',
                             self.namespaces)
+        if file is None:
+            raise ValueError('No file in attachment')
+        if 'filename' not in file.attrib:
+            raise ValueError('Attachment has no file name')
 
         self.file_name = file.attrib['filename']
         self.mime = file.attrib['mimeCode']
